package android.image;

import java.util.HashMap;
import android.graphics.Color;

/**
 * <style type='text/css'><!--
 *    .com{ font-style: italic; color: #880000; }
 *    .keyw{ font-weight: bold; color: #000088; }
 *    .num{ color: #00AA00; }
 *    .str{ color: #CC00AB; }
 *    .prim{ color: #0000FF; }
 *    .func{ color: #BB7733; }
 *    .colorName{
 *       text-align: right;
 *       padding: 5px 20px 5px 20px;
 *       color: #CC00AB;
 *    }
 *    .colorRow, .colorName, .colorBlock{
 *       border: 1px solid black;
 *       margin: 5px 0px 5px 0px;
 *    }   
 *  --></style>
 *  
 * Manages color names and translation to implementation-dependent Color structures.
 * 
 * <p>
 *    Available colors are listed in the following table.  If an undefined color is used then a RuntimeException 
 *    is thrown. Alternatively clients can specify a 7 character string beginning with a '#' (hash-mark)
 *    followed by a 6 digit hexadecimal number that encodes the requested RGB color, e.g., 
 *    <span class='str'>"#FF00FF"</span> for Red, or <span class='str'>"#00FF00"</span> for Green.
 *    Color names are <i>case-insensitive</i>.
 * </p>
 * 
 *  <center>
 *     <table class='colorTable'>
 *       <tr class='colorRow'><td class='colorName'>"orange red"</td><td class='colorBlock' style="background-color: #ff4500">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"orangered"</td><td class='colorBlock' style="background-color: #ff4500">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"tomato"</td><td class='colorBlock' style="background-color: #ff6347">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darkred"</td><td class='colorBlock' style="background-color: #8b0000">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"red"</td><td class='colorBlock' style="background-color: #ff0000">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"firebrick"</td><td class='colorBlock' style="background-color: #b22222">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"crimson"</td><td class='colorBlock' style="background-color: #dc143c">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"deeppink"</td><td class='colorBlock' style="background-color: #ff1493">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"maroon"</td><td class='colorBlock' style="background-color: #b03060">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"indian red"</td><td class='colorBlock' style="background-color: #cd5c5c">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"indianred"</td><td class='colorBlock' style="background-color: #cd5c5c">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"medium violet red"</td><td class='colorBlock' style="background-color: #c71585">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"mediumvioletred"</td><td class='colorBlock' style="background-color: #c71585">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"violet red"</td><td class='colorBlock' style="background-color: #d02090">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"violetred"</td><td class='colorBlock' style="background-color: #d02090">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lightcoral"</td><td class='colorBlock' style="background-color: #f08080">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"hotpink"</td><td class='colorBlock' style="background-color: #ff69b4">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"palevioletred"</td><td class='colorBlock' style="background-color: #db7093">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lightpink"</td><td class='colorBlock' style="background-color: #ffb6c1">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"rosybrown"</td><td class='colorBlock' style="background-color: #bc8f8f">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"pink"</td><td class='colorBlock' style="background-color: #ffc0cb">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"orchid"</td><td class='colorBlock' style="background-color: #da70d6">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lavenderblush"</td><td class='colorBlock' style="background-color: #fff0f5">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"snow"</td><td class='colorBlock' style="background-color: #fffafa">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"chocolate"</td><td class='colorBlock' style="background-color: #d2691e">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"saddlebrown"</td><td class='colorBlock' style="background-color: #8b4513">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"brown"</td><td class='colorBlock' style="background-color: #843c24">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darkorange"</td><td class='colorBlock' style="background-color: #ff8c00">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"coral"</td><td class='colorBlock' style="background-color: #ff7f50">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"sienna"</td><td class='colorBlock' style="background-color: #a0522d">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"orange"</td><td class='colorBlock' style="background-color: #ffa500">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"salmon"</td><td class='colorBlock' style="background-color: #fa8072">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"peru"</td><td class='colorBlock' style="background-color: #cd853f">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darkgoldenrod"</td><td class='colorBlock' style="background-color: #b8860b">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"goldenrod"</td><td class='colorBlock' style="background-color: #daa520">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"sandybrown"</td><td class='colorBlock' style="background-color: #f4a460">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lightsalmon"</td><td class='colorBlock' style="background-color: #ffa07a">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darksalmon"</td><td class='colorBlock' style="background-color: #e9967a">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"gold"</td><td class='colorBlock' style="background-color: #ffd700">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"yellow"</td><td class='colorBlock' style="background-color: #ffff00">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"olive"</td><td class='colorBlock' style="background-color: #808000">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"burlywood"</td><td class='colorBlock' style="background-color: #deb887">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"tan"</td><td class='colorBlock' style="background-color: #d2b48c">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"navajowhite"</td><td class='colorBlock' style="background-color: #ffdead">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"peachpuff"</td><td class='colorBlock' style="background-color: #ffdab9">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"khaki"</td><td class='colorBlock' style="background-color: #f0e68c">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darkkhaki"</td><td class='colorBlock' style="background-color: #bdb76b">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"moccasin"</td><td class='colorBlock' style="background-color: #ffe4b5">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"wheat"</td><td class='colorBlock' style="background-color: #f5deb3">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"bisque"</td><td class='colorBlock' style="background-color: #ffe4c4">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"palegoldenrod"</td><td class='colorBlock' style="background-color: #eee8aa">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"blanchedalmond"</td><td class='colorBlock' style="background-color: #ffebcd">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"medium goldenrod"</td><td class='colorBlock' style="background-color: #eaeaad">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"mediumgoldenrod"</td><td class='colorBlock' style="background-color: #eaeaad">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"papayawhip"</td><td class='colorBlock' style="background-color: #ffefd5">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"mistyrose"</td><td class='colorBlock' style="background-color: #ffe4e1">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lemonchiffon"</td><td class='colorBlock' style="background-color: #fffacd">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"antiquewhite"</td><td class='colorBlock' style="background-color: #faebd7">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"cornsilk"</td><td class='colorBlock' style="background-color: #fff8dc">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lightgoldenrodyellow"</td><td class='colorBlock' style="background-color: #fafad2">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"oldlace"</td><td class='colorBlock' style="background-color: #fdf5e6">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"linen"</td><td class='colorBlock' style="background-color: #faf0e6">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lightyellow"</td><td class='colorBlock' style="background-color: #ffffe0">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"seashell"</td><td class='colorBlock' style="background-color: #fff5ee">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"beige"</td><td class='colorBlock' style="background-color: #f5f5dc">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"floralwhite"</td><td class='colorBlock' style="background-color: #fffaf0">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"ivory"</td><td class='colorBlock' style="background-color: #fffff0">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"green"</td><td class='colorBlock' style="background-color: #00ff00">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lawngreen"</td><td class='colorBlock' style="background-color: #7cfc00">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"chartreuse"</td><td class='colorBlock' style="background-color: #7fff00">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"green yellow"</td><td class='colorBlock' style="background-color: #adff2f">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"greenyellow"</td><td class='colorBlock' style="background-color: #adff2f">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"yellow green"</td><td class='colorBlock' style="background-color: #9acd32">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"yellowgreen"</td><td class='colorBlock' style="background-color: #9acd32">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"medium forest green"</td><td class='colorBlock' style="background-color: #6b8e23">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"olivedrab"</td><td class='colorBlock' style="background-color: #6b8e23">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"mediumforestgreen"</td><td class='colorBlock' style="background-color: #6b8e23">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"dark olive green"</td><td class='colorBlock' style="background-color: #556b2f">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darkolivegreen"</td><td class='colorBlock' style="background-color: #556b2f">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darkseagreen"</td><td class='colorBlock' style="background-color: #8fbc8b">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lime"</td><td class='colorBlock' style="background-color: #00ff00">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"dark green"</td><td class='colorBlock' style="background-color: #006400">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darkgreen"</td><td class='colorBlock' style="background-color: #006400">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lime green"</td><td class='colorBlock' style="background-color: #32cd32">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"limegreen"</td><td class='colorBlock' style="background-color: #32cd32">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"forest green"</td><td class='colorBlock' style="background-color: #228b22">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"forestgreen"</td><td class='colorBlock' style="background-color: #228b22">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"spring green"</td><td class='colorBlock' style="background-color: #00ff7f">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"springgreen"</td><td class='colorBlock' style="background-color: #00ff7f">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"medium spring green"</td><td class='colorBlock' style="background-color: #00fa9a">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"mediumspringgreen"</td><td class='colorBlock' style="background-color: #00fa9a">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"sea green"</td><td class='colorBlock' style="background-color: #2e8b57">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"seagreen"</td><td class='colorBlock' style="background-color: #2e8b57">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"medium sea green"</td><td class='colorBlock' style="background-color: #3cb371">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"mediumseagreen"</td><td class='colorBlock' style="background-color: #3cb371">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"aquamarine"</td><td class='colorBlock' style="background-color: #70d890">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lightgreen"</td><td class='colorBlock' style="background-color: #90ee90">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"pale green"</td><td class='colorBlock' style="background-color: #98fb98">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"palegreen"</td><td class='colorBlock' style="background-color: #98fb98">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"medium aquamarine"</td><td class='colorBlock' style="background-color: #66cdaa">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"mediumaquamarine"</td><td class='colorBlock' style="background-color: #66cdaa">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"turquoise"</td><td class='colorBlock' style="background-color: #40e0d0">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lightseagreen"</td><td class='colorBlock' style="background-color: #20b2aa">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"medium turquoise"</td><td class='colorBlock' style="background-color: #48d1cc">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"mediumturquoise"</td><td class='colorBlock' style="background-color: #48d1cc">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"honeydew"</td><td class='colorBlock' style="background-color: #f0fff0">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"mintcream"</td><td class='colorBlock' style="background-color: #f5fffa">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"royalblue"</td><td class='colorBlock' style="background-color: #4169e1">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"dodgerblue"</td><td class='colorBlock' style="background-color: #1e90ff">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"deepskyblue"</td><td class='colorBlock' style="background-color: #00bfff">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"cornflowerblue"</td><td class='colorBlock' style="background-color: #6495ed">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"steel blue"</td><td class='colorBlock' style="background-color: #4682b4">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"steelblue"</td><td class='colorBlock' style="background-color: #4682b4">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lightskyblue"</td><td class='colorBlock' style="background-color: #87cefa">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"dark turquoise"</td><td class='colorBlock' style="background-color: #00ced1">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darkturquoise"</td><td class='colorBlock' style="background-color: #00ced1">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"cyan"</td><td class='colorBlock' style="background-color: #00ffff">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"aqua"</td><td class='colorBlock' style="background-color: #00ffff">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darkcyan"</td><td class='colorBlock' style="background-color: #008b8b">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"teal"</td><td class='colorBlock' style="background-color: #008080">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"sky blue"</td><td class='colorBlock' style="background-color: #87ceeb">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"skyblue"</td><td class='colorBlock' style="background-color: #87ceeb">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"cadet blue"</td><td class='colorBlock' style="background-color: #60a0a0">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"cadetblue"</td><td class='colorBlock' style="background-color: #5f9ea0">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"dark slate gray"</td><td class='colorBlock' style="background-color: #2f4f4f">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darkslategray"</td><td class='colorBlock' style="background-color: #2f4f4f">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lightslategray"</td><td class='colorBlock' style="background-color: #778899">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"slategray"</td><td class='colorBlock' style="background-color: #708090">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"light steel blue"</td><td class='colorBlock' style="background-color: #b0c4de">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lightsteelblue"</td><td class='colorBlock' style="background-color: #b0c4de">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"light blue"</td><td class='colorBlock' style="background-color: #add8e6">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lightblue"</td><td class='colorBlock' style="background-color: #add8e6">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"powderblue"</td><td class='colorBlock' style="background-color: #b0e0e6">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"paleturquoise"</td><td class='colorBlock' style="background-color: #afeeee">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lightcyan"</td><td class='colorBlock' style="background-color: #e0ffff">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"aliceblue"</td><td class='colorBlock' style="background-color: #f0f8ff">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"azure"</td><td class='colorBlock' style="background-color: #f0ffff">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"medium blue"</td><td class='colorBlock' style="background-color: #0000cd">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"mediumblue"</td><td class='colorBlock' style="background-color: #0000cd">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darkblue"</td><td class='colorBlock' style="background-color: #00008b">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"midnight blue"</td><td class='colorBlock' style="background-color: #191970">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"midnightblue"</td><td class='colorBlock' style="background-color: #191970">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"navy"</td><td class='colorBlock' style="background-color: #24248c">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"blue"</td><td class='colorBlock' style="background-color: #0000ff">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"indigo"</td><td class='colorBlock' style="background-color: #4b0082">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"blue violet"</td><td class='colorBlock' style="background-color: #8a2be2">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"blueviolet"</td><td class='colorBlock' style="background-color: #8a2be2">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"medium slate blue"</td><td class='colorBlock' style="background-color: #7b68ee">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"mediumslateblue"</td><td class='colorBlock' style="background-color: #7b68ee">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"slate blue"</td><td class='colorBlock' style="background-color: #6a5acd">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"slateblue"</td><td class='colorBlock' style="background-color: #6a5acd">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"purple"</td><td class='colorBlock' style="background-color: #a020f0">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"dark slate blue"</td><td class='colorBlock' style="background-color: #483d8b">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darkslateblue"</td><td class='colorBlock' style="background-color: #483d8b">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darkviolet"</td><td class='colorBlock' style="background-color: #9400d3">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"dark orchid"</td><td class='colorBlock' style="background-color: #9932cc">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darkorchid"</td><td class='colorBlock' style="background-color: #9932cc">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"mediumpurple"</td><td class='colorBlock' style="background-color: #9370db">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"cornflower blue"</td><td class='colorBlock' style="background-color: #44406c">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"medium orchid"</td><td class='colorBlock' style="background-color: #ba55d3">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"mediumorchid"</td><td class='colorBlock' style="background-color: #ba55d3">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"magenta"</td><td class='colorBlock' style="background-color: #ff00ff">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"fuchsia"</td><td class='colorBlock' style="background-color: #ff00ff">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darkmagenta"</td><td class='colorBlock' style="background-color: #8b008b">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"violet"</td><td class='colorBlock' style="background-color: #ee82ee">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"plum"</td><td class='colorBlock' style="background-color: #dda0dd">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lavender"</td><td class='colorBlock' style="background-color: #e6e6fa">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"thistle"</td><td class='colorBlock' style="background-color: #d8bfd8">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"ghostwhite"</td><td class='colorBlock' style="background-color: #f8f8ff">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"white"</td><td class='colorBlock' style="background-color: #ffffff">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"whitesmoke"</td><td class='colorBlock' style="background-color: #f5f5f5">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"gainsboro"</td><td class='colorBlock' style="background-color: #dcdcdc">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"light gray"</td><td class='colorBlock' style="background-color: #d3d3d3">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"lightgray"</td><td class='colorBlock' style="background-color: #d3d3d3">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"silver"</td><td class='colorBlock' style="background-color: #c0c0c0">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"gray"</td><td class='colorBlock' style="background-color: #bebebe">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"dark gray"</td><td class='colorBlock' style="background-color: #a9a9a9">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"darkgray"</td><td class='colorBlock' style="background-color: #a9a9a9">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"dim gray"</td><td class='colorBlock' style="background-color: #696969">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"dimgray"</td><td class='colorBlock' style="background-color: #696969">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *       <tr class='colorRow'><td class='colorName'>"black"</td><td class='colorBlock' style="background-color: #000000">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td></tr>
 *     </table>
 *   </center>
 *   
 */
public class ColorDatabase {


    /** Get the java.awt.Color represented by the given string */
    public static int color(String s){
        s = s.toLowerCase();
        if(s.startsWith("#") && s.length() == 7)
            return parseColor(s.substring(1));
        if(colorTable.containsKey(s))
            return colorTable.get(s);
        return Color.BLACK;
    }

    /** Parse a hex-Color from a 6 digit String (two each for Red, Green, Blue */
    public static int parseColor(String c){
        String red = c.substring(0,2);
        String green = c.substring(2,4);
        String blue = c.substring(4,6);
        return Color.rgb(Integer.parseInt(red, 16),
                         Integer.parseInt(green, 16),
                         Integer.parseInt(blue, 16));
    }
    
    /** Available colors... */
    private static HashMap<String, Integer> colorTable = new HashMap<String, Integer>();
    static{
        colorTable.put("orangered", Color.rgb(0xff, 0x45, 0x00));
        colorTable.put("tomato", Color.rgb(0xff, 0x63, 0x47));
        colorTable.put("darkred", Color.rgb(0x8b, 0x00, 0x00));
        colorTable.put("red", Color.rgb(0xff, 0x00, 0x00));
        colorTable.put("firebrick", Color.rgb(0xb2, 0x22, 0x22));
        colorTable.put("crimson", Color.rgb(0xdc, 0x14, 0x3c));
        colorTable.put("deeppink", Color.rgb(0xff, 0x14, 0x93));
        colorTable.put("maroon", Color.rgb(0xb0, 0x30, 0x60));
        colorTable.put("indian red", Color.rgb(0xcd, 0x5c, 0x5c));
        colorTable.put("indianred", Color.rgb(0xcd, 0x5c, 0x5c));
        colorTable.put("medium violet red", Color.rgb(0xc7, 0x15, 0x85));
        colorTable.put("mediumvioletred", Color.rgb(0xc7, 0x15, 0x85));
        colorTable.put("violet red", Color.rgb(0xd0, 0x20, 0x90));
        colorTable.put("violetred", Color.rgb(0xd0, 0x20, 0x90));
        colorTable.put("lightcoral", Color.rgb(0xf0, 0x80, 0x80));
        colorTable.put("hotpink", Color.rgb(0xff, 0x69, 0xb4));
        colorTable.put("palevioletred", Color.rgb(0xdb, 0x70, 0x93));
        colorTable.put("lightpink", Color.rgb(0xff, 0xb6, 0xc1));
        colorTable.put("rosybrown", Color.rgb(0xbc, 0x8f, 0x8f));
        colorTable.put("pink", Color.rgb(0xff, 0xc0, 0xcb));
        colorTable.put("orchid", Color.rgb(0xda, 0x70, 0xd6));
        colorTable.put("lavenderblush", Color.rgb(0xff, 0xf0, 0xf5));
        colorTable.put("snow", Color.rgb(0xff, 0xfa, 0xfa));
        colorTable.put("chocolate", Color.rgb(0xd2, 0x69, 0x1e));
        colorTable.put("saddlebrown", Color.rgb(0x8b, 0x45, 0x13));
        colorTable.put("brown", Color.rgb(0x84, 0x3c, 0x24));
        colorTable.put("darkorange", Color.rgb(0xff, 0x8c, 0x00));
        colorTable.put("coral", Color.rgb(0xff, 0x7f, 0x50));
        colorTable.put("sienna", Color.rgb(0xa0, 0x52, 0x2d));
        colorTable.put("orange", Color.rgb(0xff, 0xa5, 0x00));
        colorTable.put("salmon", Color.rgb(0xfa, 0x80, 0x72));
        colorTable.put("peru", Color.rgb(0xcd, 0x85, 0x3f));
        colorTable.put("darkgoldenrod", Color.rgb(0xb8, 0x86, 0x0b));
        colorTable.put("goldenrod", Color.rgb(0xda, 0xa5, 0x20));
        colorTable.put("sandybrown", Color.rgb(0xf4, 0xa4, 0x60));
        colorTable.put("lightsalmon", Color.rgb(0xff, 0xa0, 0x7a));
        colorTable.put("darksalmon", Color.rgb(0xe9, 0x96, 0x7a));
        colorTable.put("gold", Color.rgb(0xff, 0xd7, 0x00));
        colorTable.put("yellow", Color.rgb(0xff, 0xff, 0x00));
        colorTable.put("olive", Color.rgb(0x80, 0x80, 0x00));
        colorTable.put("burlywood", Color.rgb(0xde, 0xb8, 0x87));
        colorTable.put("tan", Color.rgb(0xd2, 0xb4, 0x8c));
        colorTable.put("navajowhite", Color.rgb(0xff, 0xde, 0xad));
        colorTable.put("peachpuff", Color.rgb(0xff, 0xda, 0xb9));
        colorTable.put("khaki", Color.rgb(0xf0, 0xe6, 0x8c));
        colorTable.put("darkkhaki", Color.rgb(0xbd, 0xb7, 0x6b));
        colorTable.put("moccasin", Color.rgb(0xff, 0xe4, 0xb5));
        colorTable.put("wheat", Color.rgb(0xf5, 0xde, 0xb3));
        colorTable.put("bisque", Color.rgb(0xff, 0xe4, 0xc4));
        colorTable.put("palegoldenrod", Color.rgb(0xee, 0xe8, 0xaa));
        colorTable.put("blanchedalmond", Color.rgb(0xff, 0xeb, 0xcd));
        colorTable.put("medium goldenrod", Color.rgb(0xea, 0xea, 0xad));
        colorTable.put("mediumgoldenrod", Color.rgb(0xea, 0xea, 0xad));
        colorTable.put("papayawhip", Color.rgb(0xff, 0xef, 0xd5));
        colorTable.put("mistyrose", Color.rgb(0xff, 0xe4, 0xe1));
        colorTable.put("lemonchiffon", Color.rgb(0xff, 0xfa, 0xcd));
        colorTable.put("antiquewhite", Color.rgb(0xfa, 0xeb, 0xd7));
        colorTable.put("cornsilk", Color.rgb(0xff, 0xf8, 0xdc));
        colorTable.put("lightgoldenrodyellow", Color.rgb(0xfa, 0xfa, 0xd2));
        colorTable.put("oldlace", Color.rgb(0xfd, 0xf5, 0xe6));
        colorTable.put("linen", Color.rgb(0xfa, 0xf0, 0xe6));
        colorTable.put("lightyellow", Color.rgb(0xff, 0xff, 0xe0));
        colorTable.put("seashell", Color.rgb(0xff, 0xf5, 0xee));
        colorTable.put("beige", Color.rgb(0xf5, 0xf5, 0xdc));
        colorTable.put("floralwhite", Color.rgb(0xff, 0xfa, 0xf0));
        colorTable.put("ivory", Color.rgb(0xff, 0xff, 0xf0));
        colorTable.put("green", Color.rgb(0x00, 0xff, 0x00));
        colorTable.put("lawngreen", Color.rgb(0x7c, 0xfc, 0x00));
        colorTable.put("chartreuse", Color.rgb(0x7f, 0xff, 0x00));
        colorTable.put("green yellow", Color.rgb(0xad, 0xff, 0x2f));
        colorTable.put("greenyellow", Color.rgb(0xad, 0xff, 0x2f));
        colorTable.put("yellow green", Color.rgb(0x9a, 0xcd, 0x32));
        colorTable.put("yellowgreen", Color.rgb(0x9a, 0xcd, 0x32));
        colorTable.put("medium forest green", Color.rgb(0x6b, 0x8e, 0x23));
        colorTable.put("olivedrab", Color.rgb(0x6b, 0x8e, 0x23));
        colorTable.put("mediumforestgreen", Color.rgb(0x6b, 0x8e, 0x23));
        colorTable.put("dark olive green", Color.rgb(0x55, 0x6b, 0x2f));
        colorTable.put("darkolivegreen", Color.rgb(0x55, 0x6b, 0x2f));
        colorTable.put("darkseagreen", Color.rgb(0x8f, 0xbc, 0x8b));
        colorTable.put("lime", Color.rgb(0x00, 0xff, 0x00));
        colorTable.put("dark green", Color.rgb(0x00, 0x64, 0x00));
        colorTable.put("darkgreen", Color.rgb(0x00, 0x64, 0x00));
        colorTable.put("lime green", Color.rgb(0x32, 0xcd, 0x32));
        colorTable.put("limegreen", Color.rgb(0x32, 0xcd, 0x32));
        colorTable.put("forest green", Color.rgb(0x22, 0x8b, 0x22));
        colorTable.put("forestgreen", Color.rgb(0x22, 0x8b, 0x22));
        colorTable.put("spring green", Color.rgb(0x00, 0xff, 0x7f));
        colorTable.put("springgreen", Color.rgb(0x00, 0xff, 0x7f));
        colorTable.put("medium spring green", Color.rgb(0x00, 0xfa, 0x9a));
        colorTable.put("mediumspringgreen", Color.rgb(0x00, 0xfa, 0x9a));
        colorTable.put("sea green", Color.rgb(0x2e, 0x8b, 0x57));
        colorTable.put("seagreen", Color.rgb(0x2e, 0x8b, 0x57));
        colorTable.put("medium sea green", Color.rgb(0x3c, 0xb3, 0x71));
        colorTable.put("mediumseagreen", Color.rgb(0x3c, 0xb3, 0x71));
        colorTable.put("aquamarine", Color.rgb(0x70, 0xd8, 0x90));
        colorTable.put("lightgreen", Color.rgb(0x90, 0xee, 0x90));
        colorTable.put("pale green", Color.rgb(0x98, 0xfb, 0x98));
        colorTable.put("palegreen", Color.rgb(0x98, 0xfb, 0x98));
        colorTable.put("medium aquamarine", Color.rgb(0x66, 0xcd, 0xaa));
        colorTable.put("mediumaquamarine", Color.rgb(0x66, 0xcd, 0xaa));
        colorTable.put("turquoise", Color.rgb(0x40, 0xe0, 0xd0));
        colorTable.put("lightseagreen", Color.rgb(0x20, 0xb2, 0xaa));
        colorTable.put("medium turquoise", Color.rgb(0x48, 0xd1, 0xcc));
        colorTable.put("mediumturquoise", Color.rgb(0x48, 0xd1, 0xcc));
        colorTable.put("honeydew", Color.rgb(0xf0, 0xff, 0xf0));
        colorTable.put("mintcream", Color.rgb(0xf5, 0xff, 0xfa));
        colorTable.put("royalblue", Color.rgb(0x41, 0x69, 0xe1));
        colorTable.put("dodgerblue", Color.rgb(0x1e, 0x90, 0xff));
        colorTable.put("deepskyblue", Color.rgb(0x00, 0xbf, 0xff));
        colorTable.put("cornflowerblue", Color.rgb(0x64, 0x95, 0xed));
        colorTable.put("steel blue", Color.rgb(0x46, 0x82, 0xb4));
        colorTable.put("steelblue", Color.rgb(0x46, 0x82, 0xb4));
        colorTable.put("lightskyblue", Color.rgb(0x87, 0xce, 0xfa));
        colorTable.put("dark turquoise", Color.rgb(0x00, 0xce, 0xd1));
        colorTable.put("darkturquoise", Color.rgb(0x00, 0xce, 0xd1));
        colorTable.put("cyan", Color.rgb(0x00, 0xff, 0xff));
        colorTable.put("aqua", Color.rgb(0x00, 0xff, 0xff));
        colorTable.put("darkcyan", Color.rgb(0x00, 0x8b, 0x8b));
        colorTable.put("teal", Color.rgb(0x00, 0x80, 0x80));
        colorTable.put("sky blue", Color.rgb(0x87, 0xce, 0xeb));
        colorTable.put("skyblue", Color.rgb(0x87, 0xce, 0xeb));
        colorTable.put("cadet blue", Color.rgb(0x60, 0xa0, 0xa0));
        colorTable.put("cadetblue", Color.rgb(0x5f, 0x9e, 0xa0));
        colorTable.put("dark slate gray", Color.rgb(0x2f, 0x4f, 0x4f));
        colorTable.put("darkslategray", Color.rgb(0x2f, 0x4f, 0x4f));
        colorTable.put("lightslategray", Color.rgb(0x77, 0x88, 0x99));
        colorTable.put("slategray", Color.rgb(0x70, 0x80, 0x90));
        colorTable.put("light steel blue", Color.rgb(0xb0, 0xc4, 0xde));
        colorTable.put("lightsteelblue", Color.rgb(0xb0, 0xc4, 0xde));
        colorTable.put("light blue", Color.rgb(0xad, 0xd8, 0xe6));
        colorTable.put("lightblue", Color.rgb(0xad, 0xd8, 0xe6));
        colorTable.put("powderblue", Color.rgb(0xb0, 0xe0, 0xe6));
        colorTable.put("paleturquoise", Color.rgb(0xaf, 0xee, 0xee));
        colorTable.put("lightcyan", Color.rgb(0xe0, 0xff, 0xff));
        colorTable.put("aliceblue", Color.rgb(0xf0, 0xf8, 0xff));
        colorTable.put("azure", Color.rgb(0xf0, 0xff, 0xff));
        colorTable.put("medium blue", Color.rgb(0x00, 0x00, 0xcd));
        colorTable.put("mediumblue", Color.rgb(0x00, 0x00, 0xcd));
        colorTable.put("darkblue", Color.rgb(0x00, 0x00, 0x8b));
        colorTable.put("midnight blue", Color.rgb(0x19, 0x19, 0x70));
        colorTable.put("midnightblue", Color.rgb(0x19, 0x19, 0x70));
        colorTable.put("navy", Color.rgb(0x24, 0x24, 0x8c));
        colorTable.put("blue", Color.rgb(0x00, 0x00, 0xff));
        colorTable.put("indigo", Color.rgb(0x4b, 0x00, 0x82));
        colorTable.put("blue violet", Color.rgb(0x8a, 0x2b, 0xe2));
        colorTable.put("blueviolet", Color.rgb(0x8a, 0x2b, 0xe2));
        colorTable.put("medium slate blue", Color.rgb(0x7b, 0x68, 0xee));
        colorTable.put("mediumslateblue", Color.rgb(0x7b, 0x68, 0xee));
        colorTable.put("slate blue", Color.rgb(0x6a, 0x5a, 0xcd));
        colorTable.put("slateblue", Color.rgb(0x6a, 0x5a, 0xcd));
        colorTable.put("purple", Color.rgb(0xa0, 0x20, 0xf0));
        colorTable.put("dark slate blue", Color.rgb(0x48, 0x3d, 0x8b));
        colorTable.put("darkslateblue", Color.rgb(0x48, 0x3d, 0x8b));
        colorTable.put("darkviolet", Color.rgb(0x94, 0x00, 0xd3));
        colorTable.put("dark orchid", Color.rgb(0x99, 0x32, 0xcc));
        colorTable.put("darkorchid", Color.rgb(0x99, 0x32, 0xcc));
        colorTable.put("mediumpurple", Color.rgb(0x93, 0x70, 0xdb));
        colorTable.put("cornflower blue", Color.rgb(0x44, 0x40, 0x6c));
        colorTable.put("medium orchid", Color.rgb(0xba, 0x55, 0xd3));
        colorTable.put("mediumorchid", Color.rgb(0xba, 0x55, 0xd3));
        colorTable.put("magenta", Color.rgb(0xff, 0x00, 0xff));
        colorTable.put("fuchsia", Color.rgb(0xff, 0x00, 0xff));
        colorTable.put("darkmagenta", Color.rgb(0x8b, 0x00, 0x8b));
        colorTable.put("violet", Color.rgb(0xee, 0x82, 0xee));
        colorTable.put("plum", Color.rgb(0xdd, 0xa0, 0xdd));
        colorTable.put("lavender", Color.rgb(0xe6, 0xe6, 0xfa));
        colorTable.put("thistle", Color.rgb(0xd8, 0xbf, 0xd8));
        colorTable.put("ghostwhite", Color.rgb(0xf8, 0xf8, 0xff));
        colorTable.put("white", Color.rgb(0xff, 0xff, 0xff));
        colorTable.put("whitesmoke", Color.rgb(0xf5, 0xf5, 0xf5));
        colorTable.put("gainsboro", Color.rgb(0xdc, 0xdc, 0xdc));
        colorTable.put("light gray", Color.rgb(0xd3, 0xd3, 0xd3));
        colorTable.put("lightgray", Color.rgb(0xd3, 0xd3, 0xd3));
        colorTable.put("silver", Color.rgb(0xc0, 0xc0, 0xc0));
        colorTable.put("gray", Color.rgb(0xbe, 0xbe, 0xbe));
        colorTable.put("dark gray", Color.rgb(0xa9, 0xa9, 0xa9));
        colorTable.put("darkgray", Color.rgb(0xa9, 0xa9, 0xa9));
        colorTable.put("dim gray", Color.rgb(0x69, 0x69, 0x69));
        colorTable.put("dimgray", Color.rgb(0x69, 0x69, 0x69));
        colorTable.put("black", Color.rgb(0x00, 0x00, 0x00));
    }
}
