package android.image;

import android.graphics.Canvas;
import android.graphics.Paint;

/**
 * <style type='text/css'><!--
 *    .com{ font-style: italic; color: #880000; }
 *    .keyw{ font-weight: bold; color: #000088; }
 *    .num{ color: #00AA00; }
 *    .str{ color: #CC00AB; }
 *    .prim{ color: #0000FF; }
 *    img.example{ padding-left: 50px; padding-bottom: 30px; }
 *  --></style>
 * 
 * Represents the empty (blank) Scene (a cropped <code>Image</code>).
 * 
 * <pre>
 *    <span class='keyw'>new</span> EmptyScene(<span class='num'>160</span>, <span class='num'>90</span>)</pre>
 * <img class="example" src="test/images/empty-scene.png" />
 * <br />
 *
 */
public class EmptyScene extends Scene{
    public static Paint white = Image.painter(Image.color("white"), Image.SOLID);
    protected int width;
    protected int height;

    /** Construct an EmptyScene of (Width x Height) */
    public EmptyScene(double width, double height){
        this(round(width), round(height));
    }
    /** Construct an EmptyScene of (Width x Height) */
    public EmptyScene(int width, int height){
        this.width = width;
        this.height = height;
    }
    /** Paint this Scene into the given graphics */
    public void paint(Canvas c, int x, int y){
        c.drawRect(x, y, width-1, height-1, white);
    }
    
    protected int leftOfPin(){ return 0; }
    protected int rightOfPin(){ return width; }
    protected int upOfPin(){ return 0; }
    protected int downOfPin(){ return height; }
    
    /** Return the Width of this Scene/Image */
    public int width(){ return width; }
    
    /** Return the Width of this Scene/Image */
    public int height(){ return height; }
}
