package android.image;

import java.util.Hashtable;
import android.graphics.*;

/** Represents an Image from a file.  The given file name is used
 *    to load the image.  Resolved path names are cached, so images
 *    are only loaded once. */
public class FromFile extends Image{
    static final Paint paint = new Paint();
    static{
        paint.setAntiAlias(true);
    }
    protected Bitmap img;
    protected int w;
    protected int h;
    
    /** Default constructor... must call init after using */
    protected FromFile(){
        super(-1,-1);
    }
    /** Initialize this FromFile with the given Bitmap */
    protected void init(Bitmap img){
        this.img = img;
        w = img.getWidth();
        h = img.getHeight();
        this.pinholeX = w/2;
        this.pinholeY = h/2;
    }
    /** Create an Image from the given file name. */
    public FromFile(String f){
        super(-1,-1);
        try{
            java.io.File file = new java.io.File(f);
            String abs = file.getCanonicalPath();
            if(loaded.containsKey(abs)){
                img = loaded.get(abs);
            }else{
                img = BitmapFactory.decodeFile(abs);
                loaded.put(abs, img);
            }
            this.init(img);
        }catch(java.io.IOException e){
            throw new RuntimeException("Image File: \""+f+"\" Not Found!");
        }
    }
    /** Draw this image into a Graphics */
    public void paint(Canvas c, int xx, int yy){
        c.drawBitmap(img, xx-pinholeX, yy-pinholeY, paint);
    }
    /** Return the width of this Image */
    public int width(){ return w; }
    /** Return the height of this Image */
    public int height(){ return h; }    

    
    /** Store File Images, to avoid multiple loads */
    private static Hashtable<String,Bitmap> loaded = new Hashtable<String,Bitmap>();
}
