package android.image;

import java.util.Hashtable;
import android.graphics.*;
import android.content.res.Resources;

/** Represents an Image from an Android Project Resource.   */
public class FromResource extends FromFile{
    
    /** Create an Image from the given Resources and ID.  In an Eclipse 
     *    Android project, adding an image to the <code>res/drawable-*</code>
     *    directories causes resource IDs to be generated in the <code>R</code>
     *    class.  The application's {@link android.content.res.Resources Resources}
     *    instance can be obtained from the current {@link android.app.Activity Activity}
     *    using {@link android.app.Activity#getResources}.  Image resource IDs are cached
     *    so that images are only loaded once. */
    public FromResource(Resources res, int id){
        try{
            if(loadedRes.containsKey(id)){
                img = loadedRes.get(id);
            }else{
                img = BitmapFactory.decodeResource(res, id);
                loadedRes.put(id, img);
            }
            this.init(img);
        }catch(Exception e){
            throw new RuntimeException("Image Resource: \""+id+"\" Not Found!");
        }
    }    
    /** Store File Images, to avoid multiple loads */
    private static Hashtable<Integer,Bitmap> loadedRes = new Hashtable<Integer,Bitmap>();
}
