package android.image;

import android.graphics.Canvas;
import android.graphics.Paint;
import android.world.Posn;

/** 
 * <style type='text/css'><!--
 *    .com{ font-style: italic; color: #880000; }
 *    .keyw{ font-weight: bold; color: #000088; }
 *    .num{ color: #00AA00; }
 *    .str{ color: #CC00AB; }
 *    .prim{ color: #0000FF; }
 *    img.example{ padding-left: 50px; padding-bottom: 30px; }
 *  --></style>
 *
 * Class representing a Line from (0,0) to the given (X,Y).
 *
 * <pre>
 *    <span class='keyw'>new</span> Line(<span class='num'>30</span>, <span class='num'>30</span>, <span class='str'>"black"</span>)</pre>
 * <img class="example" src="test/images/line-1.png" />
 * <br />
 *
 * <pre>
 *    <span class='keyw'>new</span> Line(<span class='num'>-30</span>, <span class='num'>20</span>, <span class='str'>"red"</span>)</pre>
 * <img class="example" src="test/images/line-2.png" />
 * <br />
 *
 * <pre>
 *    <span class='keyw'>new</span> Line(<span class='num'>30</span>, <span class='num'>-20</span>, <span class='str'>"red"</span>)</pre>
 * <img class="example" src="test/images/line-3.png" />
 * <br />
 *
 */
public class Line extends Image{
    int x;
    int y;
    Paint paint;

    /** Create a Line from (0,0) to doubles (X,Y) of the given color */
    public Line(double x, double y, String color){
        this((int)x,(int)y,color);
    }
    /** Create a Line from (0,0) to ints (X,Y) of the given color */
    public Line(int x, int y, String color){
        super(Math.abs(x/2),Math.abs(y/2));
        this.x = Math.abs(x);
        // Make sure Y is the only possible negative...
        if(x*y >= 0){
            this.y = Math.abs(y);
        }else{
            this.y = -Math.abs(y);
        }
        this.paint = painter(color(color), Image.OUTLINE);    
    }
    /** Create a Line from (0,0) to doubles (X,Y) of the given color */
    public Line(Posn p, String color){
        this(p.x,p.y,color);
    }
    /** Draw this image into a Graphics */
    public void paint(Canvas c, int xx, int yy){
        
        // If Y is negative, we flip the line...
        if(y >= 0)
            c.drawLine(xx-pinholeX,yy-pinholeY,xx+pinholeX,yy+pinholeY, paint);
        else
            c.drawLine(xx-pinholeX,yy+pinholeY,xx+pinholeX,yy-pinholeY, paint);
    }
    /** Return the width of this Image */
    public int width(){ return Math.abs(x)+1; }
    /** Return the height of this Image */
    public int height(){ return Math.abs(y)+1; }
}
