package android.image;

import android.graphics.Canvas;
import android.graphics.Paint;

/** 
 * <style type='text/css'><!--
 *    .com{ font-style: italic; color: #880000; }
 *    .keyw{ font-weight: bold; color: #000088; }
 *    .num{ color: #00AA00; }
 *    .str{ color: #CC00AB; }
 *    .prim{ color: #0000FF; }
 *    img.example{ padding-left: 50px; padding-bottom: 30px; }
 *  --></style>
 *  
 * Represents an Image of a Rectangle.
 *
 * <pre>
 *    <span class='keyw'>new</span> Rectangle(<span class='num'>40</span>, <span class='num'>20</span>, <span class='str'>"outline"</span>, <span class='str'>"black"</span>)</pre>
 * <img class="example" src="test/images/rectangle-1.png" />
 * <br />
 *
 * <pre>
 *    <span class='keyw'>new</span> Rectangle(<span class='num'>20</span>, <span class='num'>40</span>, <span class='str'>"solid"</span>, <span class='str'>"blue"</span>)</pre>
 * <img class="example" src="test/images/rectangle-2.png" />
 * <br />
 *  
 */
public class Rectangle extends Image{
    int width;
    int height;
    int mode;
    Paint paint;
    
    /** Create a Rectangle Image with (double) width and height, mode and color */
    public Rectangle(double width, double height, String mode, String color){
        this(round(width),round(height),mode,color);
    }
    /** Create a Rectangle Image with (int) width and height, mode and color */
    public Rectangle(int width, int height, String mode, String color){
        this(width,height,mode(mode),color(color));
    }
    /** Create a Rectangle with converted mode and color */
    private Rectangle(int width, int height, int mode, int color){
        super(width/2, height/2);
        this.width = width;
        this.height = height;
        this.mode = mode;
        this.paint = painter(color,mode);
    }
    /** Paint this Scene into the given graphics */
    public void paint(Canvas g, int x, int y){
        g.drawRect(x-width/2,y-height/2,x+width/2,y+height/2, paint);
    }
    /** Return the Width of this Image */
    public int width(){ return width; }
    /** Return the Height of this Image */
    public int height(){ return height; }
}