package android.image;

import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Typeface;

/** 
 * <style type='text/css'><!--
 *    .com{ font-style: italic; color: #880000; }
 *    .keyw{ font-weight: bold; color: #000088; }
 *    .num{ color: #00AA00; }
 *    .str{ color: #CC00AB; }
 *    .prim{ color: #0000FF; }
 *    img.example{ padding-left: 50px; padding-bottom: 30px; }
 *  --></style>
 * 
 * A Class representing an Image of a String.
 * 
 * <pre>
 *    <span class='keyw'>new</span> Text(<span class='str'>"Hello"</span>, <span class='num'>24</span>, <span class='str'>"olive"</span>)</pre>
 * <img class="example" src="test/images/text-1.png" />
 * <br />
 *
 * <pre>
 *    <span class='keyw'>new</span> Text(<span class='str'>"Goodbye"</span>, <span class='num'>36</span>, <span class='str'>"indigo"</span>)</pre>
 * <img class="example" src="test/images/text-2.png" />
 * <br />
 * 
 */
public class Text extends Image{
    protected String str;
    protected int size;
    protected Paint paint;
    protected int height, width;

    /** Construct a text Image of the given String, size, and color */
    public Text(String str, int size, String color){
        super(0,0);
        this.str = str;
        this.size = size;
        this.paint = painter(color(color), Image.SOLID);
        paint.setTypeface(Typeface.SERIF);
        paint.setTextSize(size);
        width = (int)paint.measureText(str);
        height = (int)(paint.getFontMetrics().ascent+paint.getFontMetrics().descent);
        pinholeX = width/2;
        pinholeY = height/2;
    }
    /** Paint this Image into the given graphics */
    public void paint(Canvas c, int x, int y){
        c.drawText(str, x-pinholeX, y-pinholeY, paint);
    }
    /** Return the Width of this Image */
    public int width(){ return width; }
    /** Return the Height of this Image */
    public int height(){ return height; }
}